@@ -63,30 +63,21 @@ ml_aft_survival_regression <-
     UseMethod("ml_aft_survival_regression")
   }
 
-ml_aft_survival_regression_impl <-
-  function(x,
-           formula = NULL,
-           censor_col = "censor",
-           quantile_probabilities = c(
-             0.01, 0.05, 0.1, 0.25, 0.5,
-             0.75, 0.9, 0.95, 0.99
-           ),
-           fit_intercept = TRUE,
-           max_iter = 100L,
-           tol = 1e-06,
-           aggregation_depth = 2,
-           quantiles_col = NULL,
-           features_col = "features",
-           label_col = "label",
-           prediction_col = "prediction",
-           uid = random_string("aft_survival_regression_"),
-           response = NULL,
-           features = NULL, ...) {
-    aggregation_depth <- param_min_version(x, aggregation_depth, "2.1.0")
+ml_aft_survival_regression_impl <- function(x, formula = NULL, censor_col = "censor",
+                                            quantile_probabilities = c( 0.01, 0.05, 0.1,
+                                                                        0.25, 0.5, 0.75, 0.9,
+                                                                        0.95, 0.99),
+                                            fit_intercept = TRUE, max_iter = 100L,
+                                            tol = 1e-06, aggregation_depth = 2,
+                                            quantiles_col = NULL,features_col = "features",
+                                            label_col = "label", prediction_col = "prediction",
+                                            uid = random_string("aft_survival_regression_"),
+                                            response = NULL, features = NULL, ...) {
+
+  aggregation_depth <- param_min_version(x, aggregation_depth, "2.1.0", 2)
 
     ml_process_model(
       x = x,
-      spark_class = "org.apache.spark.ml.regression.AFTSurvivalRegression",
       r_class = "ml_aft_survival_regression",
       ml_function = new_ml_model_aft_survival_regression,
       features = features,
@@ -94,16 +85,16 @@ ml_aft_survival_regression_impl <-
       uid = uid,
       formula = formula,
       invoke_steps = list(
-        setFeaturesCol = features_col,
-        setLabelCol = label_col,
-        setPredictionCol = prediction_col,
-        setFitIntercept = cast_scalar_logical(fit_intercept),
-        setMaxIter = cast_scalar_integer(max_iter),
-        setTol = cast_scalar_double(tol),
-        setCensorCol = cast_string(censor_col),
-        setQuantileProbabilities = cast_double_list(quantile_probabilities),
-        setAggregationDepth = cast_scalar_integer(aggregation_depth),
-        setQuantilesCol = cast_nullable_string(quantiles_col)
+        features_col = features_col,
+        label_col = label_col,
+        prediction_col = prediction_col,
+        fit_intercept = fit_intercept,
+        max_iter = max_iter,
+        tol = tol,
+        censor_col = censor_col,
+        quantile_probabilities = quantile_probabilities,
+        aggregation_depth = aggregation_depth,
+        quantiles_col = quantiles_col
       )
     )
   }
