@@ -4,8 +4,7 @@
 #'
 #' @template roxlate-ml-x
 #' @export
-sdf_is_streaming <- function(x)
-{
+sdf_is_streaming <- function(x) {
   sc <- spark_connection(x)
   spark_version(sc) >= "2.0.0" && invoke(spark_dataframe(x), "isStreaming")
 }
