@@ -495,7 +495,7 @@ simulate_vars_spark <- function(x, drop_groups = FALSE) {
         }
       }
     ) %>%
-    tibble::as_tibble()
+    dplyr::as_tibble()
 }
 
 #' @importFrom tidyselect tidyselect_data_proxy tidyselect_data_has_predicates
@@ -587,8 +587,18 @@ infer_required_r_packages <- function(fn) {
   ls(deps)
 }
 
+get_os <- function() {
+  if (.Platform$OS.type == "windows") {
+    "win"
+  } else if (Sys.info()["sysname"] == "Darwin") {
+    "mac"
+  } else {
+    "unix"
+  }
+}
+
 os_is_windows <- function() {
-  .Platform$OS.type == "windows"
+  get_os() == "win"
 }
 
 cast_string <- function(x) {
