@@ -96,7 +96,7 @@ spark_worker_execute_closure <- function(
     serialize_impl <- spark_worker_get_serializer(sc)
     result <- lapply(result, function(x) serialize_impl(x, NULL))
     class(result) <- c("spark_apply_binary_result", class(result))
-    result <- tibble::tibble(spark_apply_binary_result = result)
+    result <- dplyr::tibble(spark_apply_binary_result = result)
   }
 
   if (!"data.frame" %in% class(result)) {
@@ -121,7 +121,7 @@ spark_worker_maybe_serialize_list_cols_as_json <- function(config, result) {
     config$spark_version >= "2.4.0" &&
     any(sapply(result, is.list))) {
     result <- do.call(
-      tibble::tibble,
+      dplyr::tibble,
       lapply(
         result,
         function(x) {
@@ -400,7 +400,7 @@ spark_worker_apply <- function(sc, config) {
 
     df <- (
       if (config$single_binary_column) {
-        tibble::tibble(encoded = lapply(data, function(x) x[[1]]))
+        dplyr::tibble(encoded = lapply(data, function(x) x[[1]]))
       } else {
         bind_rows <- core_get_package_function("dplyr", "bind_rows")
         as_tibble <- core_get_package_function("tibble", "as_tibble")
@@ -412,7 +412,7 @@ spark_worker_apply <- function(sc, config) {
             )
           )
         } else {
-          warning("dplyr::bind_rows or tibble::as_tibble is unavailable, ",
+          warning("dplyr::bind_rows or dplyr::as_tibble is unavailable, ",
                   "falling back to rbind implementation in base R. ",
                   "Inputs with list column(s) will not work.")
 
